@@ -250,16 +250,16 @@ static int read_binding_from_xmlnode(xmlNode *node, struct nxagentSpecialKeystro
  * search order:
  *  - '-keystrokefile' commandline parameter
  *  - $NXAGENT_KEYSTROKEFILE environment variable
- *  - $HOME/.nx/config/keystroke.cfg
- *  - /etc/nxagent/keystroke.cfg
+ *  - $HOME/.nx/config/keystrokes.cfg
+ *  - /etc/nxagent/keystrokes.cfg
  *  - hardcoded traditional NX default settings
  */
 static void parse_keystroke_file(void)
 {
   char *filename = NULL;
 
-  char *homefile = "/.nx/config/keystroke.cfg";
-  char *etcfile = "/etc/nxagent/keystroke.cfg";
+  char *homefile = "/.nx/config/keystrokes.cfg";
+  char *etcfile = "/etc/nxagent/keystrokes.cfg";
 
   if (nxagentKeystrokeFile != NULL && access(nxagentKeystrokeFile, R_OK) == 0)
   {
@@ -403,10 +403,11 @@ static enum nxagentSpecialKeystroke find_keystroke(XKeyEvent *X)
 
   enum nxagentSpecialKeystroke ret = KEYSTROKE_NOTHING;
 
-  while ((cur++)->stroke != KEYSTROKE_END_MARKER) {
+  while (cur->stroke != KEYSTROKE_END_MARKER) {
     if (cur->keysym == keysym && modifier_matches(cur->modifierMask, cur->modifierAltMeta, X->state)) {
       return cur->stroke;
     }
+    cur++;
   }
 
   return ret;
